@@ -1,7 +1,7 @@
 import threading
 import unittest
+from unittest.mock import Mock
 
-import mock
 import pytest
 
 
@@ -20,7 +20,7 @@ class TestThreadingHandler(unittest.TestCase):
         h = self._makeOne()
         h.start()
         # In Python 3.3 _Event is gone, before Event is function
-        event_class = getattr(threading, '_Event', threading.Event)
+        event_class = getattr(threading, "_Event", threading.Event)
         assert isinstance(h.event_object(), event_class)
 
     def test_matching_async(self):
@@ -45,14 +45,17 @@ class TestThreadingHandler(unittest.TestCase):
         assert h._running is False
 
     def test_huge_file_descriptor(self):
-        import resource
+        try:
+            import resource
+        except ImportError:
+            self.skipTest("resource module unavailable on this platform")
         import socket
         from kazoo.handlers.utils import create_tcp_socket
 
         try:
             resource.setrlimit(resource.RLIMIT_NOFILE, (4096, 4096))
         except (ValueError, resource.error):
-            self.skipTest('couldnt raise fd limit high enough')
+            self.skipTest("couldnt raise fd limit high enough")
         fd = 0
         socks = []
         while fd < 4000:
@@ -79,37 +82,37 @@ class TestThreadingAsync(unittest.TestCase):
         return SequentialThreadingHandler()
 
     def test_ready(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         assert async_result.ready() is False
-        async_result.set('val')
+        async_result.set("val")
         assert async_result.ready() is True
         assert async_result.successful() is True
         assert async_result.exception is None
 
     def test_callback_queued(self):
-        mock_handler = mock.Mock()
-        mock_handler.completion_queue = mock.Mock()
+        mock_handler = Mock()
+        mock_handler.completion_queue = Mock()
         async_result = self._makeOne(mock_handler)
 
         async_result.rawlink(lambda a: a)
-        async_result.set('val')
+        async_result.set("val")
 
         assert mock_handler.completion_queue.put.called
 
     def test_set_exception(self):
-        mock_handler = mock.Mock()
-        mock_handler.completion_queue = mock.Mock()
+        mock_handler = Mock()
+        mock_handler.completion_queue = Mock()
         async_result = self._makeOne(mock_handler)
         async_result.rawlink(lambda a: a)
-        async_result.set_exception(ImportError('Error occured'))
+        async_result.set_exception(ImportError("Error occured"))
 
         assert isinstance(async_result.exception, ImportError)
         assert mock_handler.completion_queue.put.called
 
     def test_get_wait_while_setting(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -126,13 +129,13 @@ class TestThreadingAsync(unittest.TestCase):
         th.start()
         bv.wait()
 
-        async_result.set('fred')
+        async_result.set("fred")
         cv.wait()
-        assert lst == ['fred']
+        assert lst == ["fred"]
         th.join()
 
     def test_get_with_nowait(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
         timeout = self._makeHandler().timeout_exception
 
@@ -143,7 +146,7 @@ class TestThreadingAsync(unittest.TestCase):
             async_result.get_nowait()
 
     def test_get_with_exception(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -155,7 +158,7 @@ class TestThreadingAsync(unittest.TestCase):
             try:
                 val = async_result.get()
             except ImportError:
-                lst.append('oops')
+                lst.append("oops")
             else:
                 lst.append(val)
             cv.set()
@@ -166,11 +169,11 @@ class TestThreadingAsync(unittest.TestCase):
 
         async_result.set_exception(ImportError)
         cv.wait()
-        assert lst == ['oops']
+        assert lst == ["oops"]
         th.join()
 
     def test_wait(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -182,7 +185,7 @@ class TestThreadingAsync(unittest.TestCase):
             try:
                 val = async_result.wait(10)
             except ImportError:
-                lst.append('oops')
+                lst.append("oops")
             else:
                 lst.append(val)
             cv.set()
@@ -202,7 +205,7 @@ class TestThreadingAsync(unittest.TestCase):
         Guards against the reappearance of:
             https://github.com/python-zk/kazoo/issues/485
         """
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         async_result.set("immediate")
@@ -225,12 +228,12 @@ class TestThreadingAsync(unittest.TestCase):
         th.join()
 
     def test_set_before_wait(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
         cv = threading.Event()
-        async_result.set('fred')
+        async_result.set("fred")
 
         def wait_for_val():
             val = async_result.get()
@@ -240,11 +243,11 @@ class TestThreadingAsync(unittest.TestCase):
         th = threading.Thread(target=wait_for_val)
         th.start()
         cv.wait()
-        assert lst == ['fred']
+        assert lst == ["fred"]
         th.join()
 
     def test_set_exc_before_wait(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -255,7 +258,7 @@ class TestThreadingAsync(unittest.TestCase):
             try:
                 val = async_result.get()
             except ImportError:
-                lst.append('ooops')
+                lst.append("ooops")
             else:
                 lst.append(val)
             cv.set()
@@ -263,11 +266,11 @@ class TestThreadingAsync(unittest.TestCase):
         th = threading.Thread(target=wait_for_val)
         th.start()
         cv.wait()
-        assert lst == ['ooops']
+        assert lst == ["ooops"]
         th.join()
 
     def test_linkage(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
         cv = threading.Event()
 
@@ -284,15 +287,15 @@ class TestThreadingAsync(unittest.TestCase):
         th.start()
 
         async_result.rawlink(add_on)
-        async_result.set(b'fred')
+        async_result.set(b"fred")
         assert mock_handler.completion_queue.put.called
         async_result.unlink(add_on)
         cv.wait()
-        assert async_result.value == b'fred'
+        assert async_result.value == b"fred"
         th.join()
 
     def test_linkage_not_ready(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -300,13 +303,13 @@ class TestThreadingAsync(unittest.TestCase):
         def add_on():
             lst.append(True)
 
-        async_result.set('fred')
+        async_result.set("fred")
         assert not mock_handler.completion_queue.called
         async_result.rawlink(add_on)
         assert mock_handler.completion_queue.put.called
 
     def test_link_and_unlink(self):
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -317,13 +320,13 @@ class TestThreadingAsync(unittest.TestCase):
         async_result.rawlink(add_on)
         assert not mock_handler.completion_queue.put.called
         async_result.unlink(add_on)
-        async_result.set('fred')
+        async_result.set("fred")
         assert not mock_handler.completion_queue.put.called
 
     def test_captured_exception(self):
         from kazoo.handlers.utils import capture_exceptions
 
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         @capture_exceptions(async_result)
@@ -338,7 +341,7 @@ class TestThreadingAsync(unittest.TestCase):
     def test_no_capture_exceptions(self):
         from kazoo.handlers.utils import capture_exceptions
 
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -359,7 +362,7 @@ class TestThreadingAsync(unittest.TestCase):
     def test_wraps(self):
         from kazoo.handlers.utils import wrap
 
-        mock_handler = mock.Mock()
+        mock_handler = Mock()
         async_result = self._makeOne(mock_handler)
 
         lst = []
@@ -371,22 +374,22 @@ class TestThreadingAsync(unittest.TestCase):
 
         @wrap(async_result)
         def regular_function():
-            return 'hello'
+            return "hello"
 
-        assert regular_function() == 'hello'
+        assert regular_function() == "hello"
         assert mock_handler.completion_queue.put.called
-        assert async_result.get() == 'hello'
+        assert async_result.get() == "hello"
 
     def test_multiple_callbacks(self):
-        mockback1 = mock.Mock(name='mockback1')
-        mockback2 = mock.Mock(name='mockback2')
+        mockback1 = Mock(name="mockback1")
+        mockback2 = Mock(name="mockback2")
         handler = self._makeHandler()
         handler.start()
 
         async_result = self._makeOne(handler)
         async_result.rawlink(mockback1)
         async_result.rawlink(mockback2)
-        async_result.set('howdy')
+        async_result.set("howdy")
         async_result.wait()
         handler.stop()
 
